Paginate and PaginateInline: Returning data in pages
====================================================

The Paginate and PaginateInline extensions lets recipes be paginated, searched and sorted.


.. module:: recipe

.. autoclass:: Paginate
    :members: apply_pagination,apply_pagination_filters,pagination_order_by,pagination_page,pagination_q,pagination_search_keys
    :noindex:

.. autoclass:: PaginateInline
    :members: apply_pagination,apply_pagination_filters,pagination_order_by,pagination_page,pagination_q,pagination_search_keys
    :noindex:
